@@ -1,5 +1,5 @@
 package Bundle::Template::Magic;
-$VERSION = 1.02;
+$VERSION = 1.03;
 __END__
 
 =head1 NAME
@@ -36,6 +36,8 @@ Note: A Bundle is a module that simply defines a collection of other modules. It
 
 =head1 AUTHOR and COPYRIGHT
 
- 2004 by Domizio Demichelis.
+ 2002-2004 by Domizio Demichelis.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as perl itself.
+
+
